==> react-bootstrap-date-picker-4.0.7.tgz: react-bootstrap-date-picker/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-date-picker`

# Summary
This package contains type definitions for react-bootstrap-date-picker (https://github.com/pushtell/react-bootstrap-date-picker#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-date-picker.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-date-picker/index.d.ts)
````ts
// Type definitions for react-bootstrap-date-picker 4.0
// Project: https://github.com/pushtell/react-bootstrap-date-picker#readme
// Definitions by: Karol Janyst <https://github.com/LKay>, Antal Bodnar <https://github.com/ssi-hu-antal-bodnar>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.8

import { ComponentClass, StatelessComponent, ReactNode, FocusEventHandler, HTMLAttributes } from "react";

export as namespace DatePicker;

export = DatePicker;

declare const DatePicker: DatePicker;
type DatePicker = ComponentClass<DatePicker.DatePickerProps>;

declare namespace DatePicker {
    type ChangeCallback = (value: string, formattedValue: string) => void;

    interface DatePickerProps {
        value?: string | undefined;
        defaultValue?: string | undefined;
        minDate?: string | undefined;
        maxDate?: string | undefined;
        style?: any;
        className?: string | undefined;
        autoFocus?: boolean | undefined;
        disabled?: boolean | undefined;
        onChange?: ChangeCallback | undefined;
        onFocus?: FocusEventHandler<any> | undefined;
        onBlur?: FocusEventHandler<any> | undefined;
        dateFormat?: string | undefined;
        clearButtonElement?: ReactNode | undefined;
        showClearButton?: boolean | undefined;
        onClear?(): void;
        previousButtonElement?: ReactNode | undefined;
        nextButtonElement?: ReactNode | undefined;
        cellPadding?: string | undefined;
        dayLabels?: string[] | undefined;
        monthLabels?: string[] | undefined;
        calendarPlacement?: string | undefined;
        calendarContainer?: any;
        weekStartsOnMonday?: boolean | undefined;
        showTodayButton?: boolean | undefined;
        todayButtonLabel?: string | undefined;
        customControl?: StatelessComponent<any> | ComponentClass<any> | undefined;
    }
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 20:20:27 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)
 * Global values: `DatePicker`

# Credits
These definitions were written by [Karol Janyst](https://github.com/LKay), and [Antal Bodnar](https://github.com/ssi-hu-antal-bodnar).

==> react-bootstrap-date-picker-4.0.8.tgz: react-bootstrap-date-picker/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-date-picker`

# Summary
This package contains type definitions for react-bootstrap-date-picker (https://github.com/pushtell/react-bootstrap-date-picker#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-date-picker.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-date-picker/index.d.ts)
````ts
// Type definitions for react-bootstrap-date-picker 4.0
// Project: https://github.com/pushtell/react-bootstrap-date-picker#readme
// Definitions by: Karol Janyst <https://github.com/LKay>, Antal Bodnar <https://github.com/ssi-hu-antal-bodnar>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.8

import { ComponentClass, FunctionComponent, ReactNode, FocusEventHandler, HTMLAttributes } from "react";

export as namespace DatePicker;

export = DatePicker;

declare const DatePicker: DatePicker;
type DatePicker = ComponentClass<DatePicker.DatePickerProps>;

declare namespace DatePicker {
    type ChangeCallback = (value: string, formattedValue: string) => void;

    interface DatePickerProps {
        value?: string | undefined;
        defaultValue?: string | undefined;
        minDate?: string | undefined;
        maxDate?: string | undefined;
        style?: any;
        className?: string | undefined;
        autoFocus?: boolean | undefined;
        disabled?: boolean | undefined;
        onChange?: ChangeCallback | undefined;
        onFocus?: FocusEventHandler<any> | undefined;
        onBlur?: FocusEventHandler<any> | undefined;
        dateFormat?: string | undefined;
        clearButtonElement?: ReactNode | undefined;
        showClearButton?: boolean | undefined;
        onClear?(): void;
        previousButtonElement?: ReactNode | undefined;
        nextButtonElement?: ReactNode | undefined;
        cellPadding?: string | undefined;
        dayLabels?: string[] | undefined;
        monthLabels?: string[] | undefined;
        calendarPlacement?: string | undefined;
        calendarContainer?: any;
        weekStartsOnMonday?: boolean | undefined;
        showTodayButton?: boolean | undefined;
        todayButtonLabel?: string | undefined;
        customControl?: FunctionComponent<any> | ComponentClass<any> | undefined;
    }
}

````

### Additional Details
 * Last updated: Wed, 20 Oct 2021 21:01:37 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)
 * Global values: `DatePicker`

# Credits
These definitions were written by [Karol Janyst](https://github.com/LKay), and [Antal Bodnar](https://github.com/ssi-hu-antal-bodnar).
